import type { KeyValueLike } from "../common.js";
/**
 * **\[🅰️ Advanced\]** Communicate with the GitHub Actions runner via the stdout command.
 */
export declare class GitHubActionsStdOutCommand {
    #private;
    get [Symbol.toStringTag](): string;
    /**
     * **\[🅰️ Advanced\]** Create new stdout command to communicate with the GitHub Actions runner.
     * @param {string} command StdOut command.
     * @param {string} [message] Message of the stdout command.
     */
    constructor(command: string, message?: string);
    /**
     * **\[🅰️ Advanced\]** Create new stdout command to communicate with the GitHub Actions runner.
     * @param {string} command StdOut command.
     * @param {KeyValueLike} properties Properties of the stdout command.
     * @param {string} [message] Message of the stdout command.
     */
    constructor(command: string, properties: KeyValueLike, message?: string);
    /**
     * Stringify the stdout command.
     * @returns {string}
     */
    toString(): string;
    /**
     * Dispatch the stdout command.
     * @returns {void}
     */
    dispatch(): void;
}
/**
 * Disable echo most of the stdout commands, the log will not print the stdout command itself unless there has any issue.
 *
 * Environment variable `ACTIONS_STEP_DEBUG` will ignore this setting.
 * @returns {void}
 */
export declare function disableEchoStdOutCommand(): void;
/**
 * Enable echo most of the stdout commands, the log will print the stdout command itself.
 *
 * Environment variable `ACTIONS_STEP_DEBUG` will ignore this setting.
 * @returns {void}
 */
export declare function enableEchoStdOutCommand(): void;
/**
 * Disable process all of the stdout commands, to allow log anything without accidentally execute any stdout command.
 * @param {string} [endToken] An end token for re-enable stdout command process.
 * @returns {string} An end token for re-enable stdout command process.
 */
export declare function disableProcessStdOutCommand(endToken?: string): string;
/**
 * Enable process all of the stdout commands, to allow execute any stdout command.
 * @param {string} endToken An end token from disable stdout command process.
 * @returns {void}
 */
export declare function enableProcessStdOutCommand(endToken: string): void;
//# sourceMappingURL=stdout.d.ts.map