import type { KeyValueLike } from "./common.js";
/**
 * Add value to the `PATH`.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_PATH`
 * >     - `PATH`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @param {string} path Value that need to add to the `PATH`.
 * @param {GitHubActionsSetEnvironmentVariableOptions} [options={}] Options.
 * @returns {void}
 */
export declare function addPATH(path: string, options?: GitHubActionsSetEnvironmentVariableOptions): void;
/**
 * Add value to the `PATH`.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_PATH`
 * >     - `PATH`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @param {string[]} paths Value that need to add to the `PATH`.
 * @param {GitHubActionsSetEnvironmentVariableOptions} [options={}] Options.
 * @returns {void}
 */
export declare function addPATH(paths: string[], options?: GitHubActionsSetEnvironmentVariableOptions): void;
/**
 * **\[🅰️ Advanced\]** Clear the environment variables for all of the subsequent steps which set in the current step.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_ENV`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @returns {void}
 */
export declare function clearEnvironmentVariableSubsequent(): void;
export { clearEnvironmentVariableSubsequent as clearEnvSubsequent };
/**
 * **\[🅰️ Advanced\]** Clear the `PATH` for all of the subsequent steps which set in the current step.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_PATH`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @returns {void}
 */
export declare function clearPATHSubsequent(): void;
/**
 * **\[🅰️ Advanced\]** Optimize the environment variables for all of the subsequent steps which set in the current step to reduce size whenever possible.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_ENV`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @returns {void}
 */
export declare function optimizeEnvironmentVariableSubsequent(): void;
export { optimizeEnvironmentVariableSubsequent as optimizeEnvSubsequent };
/**
 * **\[🅰️ Advanced\]** Optimize the `PATH` for all of the subsequent steps which set in the current step to reduce size whenever possible.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_PATH`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @returns {void}
 */
export declare function optimizePATHSubsequent(): void;
export interface GitHubActionsSetEnvironmentVariableOptions {
    /**
     * Whether to set for the current step.
     * @default {true}
     */
    scopeCurrent?: boolean;
    /**
     * Whether to set for all of the subsequent steps.
     * @default {true}
     */
    scopeSubsequent?: boolean;
}
/**
 * Set an environment variable.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @param {string} key Key of the environment variable.
 * @param {string} value Value of the environment variable.
 * @param {GitHubActionsSetEnvironmentVariableOptions} [options={}] Options.
 * @returns {void}
 */
export declare function setEnvironmentVariable(key: string, value: string, options?: GitHubActionsSetEnvironmentVariableOptions): void;
/**
 * Set the environment variables.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_ENV`
 * >     - *Resources*
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @param {KeyValueLike} pairs Pairs of the environment variable.
 * @param {GitHubActionsSetEnvironmentVariableOptions} [options={}] Options.
 * @returns {void}
 */
export declare function setEnvironmentVariable(pairs: KeyValueLike, options?: GitHubActionsSetEnvironmentVariableOptions): void;
export { setEnvironmentVariable as setEnv };
//# sourceMappingURL=environment_variable.d.ts.map