import { type JSONArray, type JSONObject, type JSONPrimitive, type JSONValue } from "@hugoalh/is-json";
import type { KeyValueLike } from "./common.js";
export type { JSONArray, JSONObject, JSONPrimitive, JSONValue };
/**
 * **\[🅰️ Advanced\]** Clear the outputs which set in the current step.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_OUTPUT`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @returns {void}
 */
export declare function clearOutput(): void;
/**
 * **\[🅰️ Advanced\]** Clear the states which set in the current step.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_STATE`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @returns {void}
 */
export declare function clearState(): void;
export interface GitHubActionsGetParameterOptions {
    /**
     * Whether to return the fallback value instead of `undefined` when the parameter is not required and defined.
     *
     * Different parameter types have different fallback value:
     *
     * - **`bigint`**: `0n`
     * - **`boolean`**: `false`
     * - **`number`**: `0`
     * - **`string`**: `""`
     * - **`JSONArray`**: `[]`
     * - **`JSONObject`**: `{}`
     * - **`JSONPrimitive`**: `null`
     * - **`JSONValue`**: `null`
     *
     * If property {@linkcode require} is defined to `true`, define this property is pointless.
     * @default {true}
     */
    fallback?: boolean;
    /**
     * Whether the parameter is require.
     *
     * If the parameter is required and not defined, will raise an error.
     * @default {false}
     */
    require?: boolean;
}
/**
 * Get the string value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {string} String value of the input.
 */
export declare function getInput(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): string;
/**
 * Get the string value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {string} String value of the input.
 */
export declare function getInput(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): string;
/**
 * Get the string value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {string | undefined} String value of the input.
 */
export declare function getInput(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): string | undefined;
export { getInput as getInputString };
/**
 * Get the big integer value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {bigint} Big integer value of the input.
 */
export declare function getInputBigInt(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): bigint;
/**
 * Get the big integer value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {bigint} Big integer value of the input.
 */
export declare function getInputBigInt(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): bigint;
/**
 * Get the big integer value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {bigint | undefined} Big integer value of the input.
 */
export declare function getInputBigInt(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): bigint | undefined;
export { getInputBigInt as getInputBigInteger };
/**
 * Get the boolean value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {boolean} Boolean value of the input.
 */
export declare function getInputBoolean(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): boolean;
/**
 * Get the boolean value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {boolean} Boolean value of the input.
 */
export declare function getInputBoolean(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): boolean;
/**
 * Get the boolean value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {boolean | undefined} Boolean value of the input.
 */
export declare function getInputBoolean(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): boolean | undefined;
/**
 * Get the JSON value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {JSONValue} JSON value of the input.
 */
export declare function getInputJSON(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): JSONValue;
/**
 * Get the JSON value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {JSONValue} JSON value of the input.
 */
export declare function getInputJSON(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): JSONValue;
/**
 * Get the JSON value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {JSONValue | undefined} JSON value of the input.
 */
export declare function getInputJSON(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): JSONValue | undefined;
export { getInputJSON as getInputJSONValue };
/**
 * Get the JSON array of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {JSONArray} JSON array of the input.
 */
export declare function getInputJSONArray(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): JSONArray;
/**
 * Get the JSON array of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {JSONArray} JSON array of the input.
 */
export declare function getInputJSONArray(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): JSONArray;
/**
 * Get the JSON array of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {JSONArray | undefined} JSON array of the input.
 */
export declare function getInputJSONArray(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): JSONArray | undefined;
/**
 * Get the JSON object of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {JSONObject} JSON object of the input.
 */
export declare function getInputJSONObject(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): JSONObject;
/**
 * Get the JSON object of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {JSONObject} JSON object of the input.
 */
export declare function getInputJSONObject(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): JSONObject;
/**
 * Get the JSON object of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {JSONObject | undefined} JSON object of the input.
 */
export declare function getInputJSONObject(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): JSONObject | undefined;
/**
 * Get the JSON primitive of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {JSONPrimitive} JSON primitive of the input.
 */
export declare function getInputJSONPrimitive(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): JSONPrimitive;
/**
 * Get the JSON primitive of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {JSONPrimitive} JSON primitive of the input.
 */
export declare function getInputJSONPrimitive(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): JSONPrimitive;
/**
 * Get the JSON primitive of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {JSONPrimitive | undefined} JSON primitive of the input.
 */
export declare function getInputJSONPrimitive(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): JSONPrimitive | undefined;
/**
 * Get the number value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {number} Number value of the input.
 */
export declare function getInputNumber(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): number;
/**
 * Get the number value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {number} Number value of the input.
 */
export declare function getInputNumber(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): number;
/**
 * Get the number value of an input.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the input.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {number | undefined} Number value of the input.
 */
export declare function getInputNumber(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): number | undefined;
/**
 * Get the string value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {string} String value of the state.
 */
export declare function getState(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): string;
/**
 * Get the string value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {string} String value of the state.
 */
export declare function getState(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): string;
/**
 * Get the string value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {string | undefined} String value of the state.
 */
export declare function getState(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): string | undefined;
export { getState as getStateString };
/**
 * Get the big integer value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {bigint} Big integer value of the state.
 */
export declare function getStateBigInt(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): bigint;
/**
 * Get the big integer value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {bigint} Big integer value of the state.
 */
export declare function getStateBigInt(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): bigint;
/**
 * Get the big integer value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {bigint | undefined} Big integer value of the state.
 */
export declare function getStateBigInt(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): bigint | undefined;
export { getStateBigInt as getStateBigInteger };
/**
 * Get the boolean value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {boolean} Boolean value of the state.
 */
export declare function getStateBoolean(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): boolean;
/**
 * Get the boolean value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {boolean} Boolean value of the state.
 */
export declare function getStateBoolean(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): boolean;
/**
 * Get the boolean value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {boolean | undefined} Boolean value of the state.
 */
export declare function getStateBoolean(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): boolean | undefined;
/**
 * Get the JSON value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {JSONValue} JSON value of the state.
 */
export declare function getStateJSON(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): JSONValue;
/**
 * Get the JSON value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {JSONValue} JSON value of the state.
 */
export declare function getStateJSON(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): JSONValue;
/**
 * Get the JSON value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {JSONValue | undefined} JSON value of the state.
 */
export declare function getStateJSON(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): JSONValue | undefined;
export { getStateJSON as getStateJSONValue };
/**
 * Get the JSON array of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {JSONArray} JSON array of the state.
 */
export declare function getStateJSONArray(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): JSONArray;
/**
 * Get the JSON array of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {JSONArray} JSON array of the state.
 */
export declare function getStateJSONArray(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): JSONArray;
/**
 * Get the JSON array of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {JSONArray | undefined} JSON array of the state.
 */
export declare function getStateJSONArray(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): JSONArray | undefined;
/**
 * Get the JSON object of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {JSONObject} JSON object of the state.
 */
export declare function getStateJSONObject(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): JSONObject;
/**
 * Get the JSON object of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {JSONObject} JSON object of the state.
 */
export declare function getStateJSONObject(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): JSONObject;
/**
 * Get the JSON object of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {JSONObject | undefined} JSON object of the state.
 */
export declare function getStateJSONObject(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): JSONObject | undefined;
/**
 * Get the JSON primitive of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {JSONPrimitive} JSON primitive of the state.
 */
export declare function getStateJSONPrimitive(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): JSONPrimitive;
/**
 * Get the JSON primitive of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {JSONPrimitive} JSON primitive of the state.
 */
export declare function getStateJSONPrimitive(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): JSONPrimitive;
/**
 * Get the JSON primitive of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {JSONPrimitive | undefined} JSON primitive of the state.
 */
export declare function getStateJSONPrimitive(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): JSONPrimitive | undefined;
/**
 * Get the number value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback?: true; require?: false; }} [options={}] Options.
 * @returns {number} Number value of the state.
 */
export declare function getStateNumber(key: string, options?: GitHubActionsGetParameterOptions & {
    fallback?: true;
    require?: false;
}): number;
/**
 * Get the number value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { require: true; }} options Options.
 * @returns {number} Number value of the state.
 */
export declare function getStateNumber(key: string, options: GitHubActionsGetParameterOptions & {
    require: true;
}): number;
/**
 * Get the number value of a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {GitHubActionsGetParameterOptions & { fallback: false; require?: false; }} options Options.
 * @returns {number | undefined} Number value of the state.
 */
export declare function getStateNumber(key: string, options: GitHubActionsGetParameterOptions & {
    fallback: false;
    require?: false;
}): number | undefined;
/**
 * **\[🅰️ Advanced\]** Optimize the outputs which set in the current step to reduce size whenever possible.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_OUTPUT`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @returns {void}
 */
export declare function optimizeOutput(): void;
/**
 * **\[🅰️ Advanced\]** Optimize the states which set in the current step to reduce size whenever possible.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_STATE`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @returns {void}
 */
export declare function optimizeState(): void;
/**
 * Set an output.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_OUTPUT`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @param {string} key Key of the output.
 * @param {string} value Value of the output.
 * @returns {void}
 */
export declare function setOutput(key: string, value: string): void;
/**
 * Set the outputs.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_OUTPUT`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @param {KeyValueLike} pairs Pairs of the output.
 * @returns {void}
 */
export declare function setOutput(pairs: KeyValueLike): void;
/**
 * Set a state.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_STATE`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @param {string} key Key of the state.
 * @param {string} value Value of the state.
 * @returns {void}
 */
export declare function setState(key: string, value: string): void;
/**
 * Set the states.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_STATE`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * >   - File System - Write (`write`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * >   - File System - Write (`fs-write`)
 * >     - *Resources*
 * @param {KeyValueLike} pairs Pairs of the state.
 * @returns {void}
 */
export declare function setState(pairs: KeyValueLike): void;
//# sourceMappingURL=parameter.d.ts.map