import { isStringSingleLine } from "@hugoalh/is-string-singleline";
import { GitHubActionsStdOutCommand } from "./command/stdout.js";
/**
 * Add problem matcher to scan the logs by specified regular expression patterns and automatically surface that information prominently in the user interface, both annotation and log decoration will create when a match is detected.
 *
 * For more information, please visit https://github.com/actions/toolkit/blob/main/docs/problem-matchers.md.
 * @param {...string} paths Path of the JSON problem matcher file.
 * @returns {void}
 */
export function addProblemMatcher(...paths) {
    paths.forEach((path) => {
        if (!(isStringSingleLine(path) && path.length > 0)) {
            throw new SyntaxError(`\`${path}\` is not a string which is non empty and single line!`);
        }
    });
    paths.forEach((path) => {
        new GitHubActionsStdOutCommand("add-matcher", path).dispatch();
    });
}
/**
 * Remove problem matcher.
 *
 * For more information, please visit https://github.com/actions/toolkit/blob/main/docs/problem-matchers.md.
 * @param {...string} names Name of the problem matcher.
 * @returns {void}
 */
export function removeProblemMatcher(...names) {
    names.forEach((name) => {
        if (!(isStringSingleLine(name) && name.length > 0)) {
            throw new SyntaxError(`\`${name}\` is not a string which is non empty and single line!`);
        }
    });
    names.forEach((name) => {
        new GitHubActionsStdOutCommand("remove-matcher", { owner: name }).dispatch();
    });
}
