import type { JSONObjectExtend, JSONValueExtend } from "@hugoalh/is-json";
/**
 * Get the URL of the GitHub API.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_API_URL`
 * @returns {URL} URL of the GitHub API.
 * @example
 * ```ts
 * getGitHubAPIURL();
 * //=> https://api.github.com
 * ```
 */
export declare function getGitHubAPIURL(): URL;
/**
 * Get the URL of the GitHub GraphQL API.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_GRAPHQL_URL`
 * @returns {URL} URL of the GitHub GraphQL API.
 * @example
 * ```ts
 * getGitHubGraphQLAPIURL();
 * //=> https://api.github.com/graphql
 * ```
 */
export declare function getGitHubGraphQLAPIURL(): URL;
/**
 * Get the URL of the GitHub server.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_SERVER_URL`
 * @returns {URL} URL of the GitHub server.
 * @example
 * ```ts
 * getGitHubServerURL();
 * //=> https://github.com
 * ```
 */
export declare function getGitHubServerURL(): URL;
/**
 * Get the name of the workflow.
 *
 * If the workflow file does not specify a name, then the value is the full path of the workflow file in the repository.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_WORKFLOW`
 * @returns {string} Name of the workflow.
 * @example
 * ```ts
 * getWorkflowName();
 * //=> "My test workflow"
 * ```
 */
export declare function getWorkflowName(): string;
/**
 * Get the reference path of the workflow.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_WORKFLOW_REF`
 * @returns {string} Reference path of the workflow.
 * @example
 * ```ts
 * getWorkflowPath();
 * //=> "octocat/hello-world/.github/workflows/my-workflow.yml@refs/heads/my_branch"
 * ```
 */
export declare function getWorkflowReferencePath(): string;
/**
 * Get the repository of the workflow.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_REPOSITORY`
 * @returns {string} Repository of the workflow.
 * @example
 * ```ts
 * getWorkflowRepository();
 * //=> "octocat/Hello-World"
 * ```
 */
export declare function getWorkflowRepository(): string;
/**
 * Get the repository ID of the workflow.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_REPOSITORY_ID`
 * @returns {string} Repository ID of the workflow.
 * @example
 * ```ts
 * getWorkflowRepositoryID();
 * //=> "123456789"
 * ```
 */
export declare function getWorkflowRepositoryID(): string;
/**
 * Get the repository owner of the workflow.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_REPOSITORY_OWNER`
 * @returns {string} Repository owner of the workflow.
 * @example
 * ```ts
 * getWorkflowRepositoryOwner();
 * //=> "octocat"
 * ```
 */
export declare function getWorkflowRepositoryOwner(): string;
/**
 * Get the repository owner ID of the workflow.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_REPOSITORY_OWNER_ID`
 * @returns {string} Repository owner ID of the workflow.
 * @example
 * ```ts
 * getWorkflowRepositoryOwnerID();
 * //=> "1234567"
 * ```
 */
export declare function getWorkflowRepositoryOwnerID(): string;
/**
 * Get the action ID of the workflow run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_ACTION`
 * @returns {string} Action ID of the workflow run.
 * @example
 * ```ts
 * getWorkflowRunActionID();
 * //=> "__repo-owner_name-of-action-repo"
 * ```
 */
export declare function getWorkflowRunActionID(): string;
/**
 * Get the actor ID of the workflow run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_ACTOR_ID`
 * @returns {string} Actor ID of the workflow run.
 * @example
 * ```ts
 * getWorkflowRunActorID();
 * //=> "1234567"
 * ```
 */
export declare function getWorkflowRunActorID(): string;
/**
 * Get the actor name that initiate the workflow run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_ACTOR`
 * @returns {string} Actor name that initiate the workflow run.
 * @example
 * ```ts
 * getWorkflowRunActorName();
 * //=> "octocat"
 * ```
 */
export declare function getWorkflowRunActorName(): string;
/**
 * Get the commit SHA that trigger the workflow run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_SHA`
 * @returns {string} Commit SHA that trigger the workflow run.
 * @example
 * ```ts
 * getWorkflowRunCommitSHA();
 * //=> "ffac537e6cbbf934b08745a378932722df287a53"
 * ```
 */
export declare function getWorkflowRunCommitSHA(): string;
export declare const eventsName: readonly ["branch_protection_rule", "check_run", "check_suite", "create", "delete", "deployment", "deployment_status", "discussion", "discussion_comment", "fork", "gollum", "issue_comment", "issues", "label", "merge_group", "milestone", "page_build", "project", "project_card", "project_column", "public", "pull_request", "pull_request_comment", "pull_request_review", "pull_request_review_comment", "pull_request_target", "push", "registry_package", "release", "repository_dispatch", "schedule", "status", "watch", "workflow_call", "workflow_dispatch", "workflow_run"];
/**
 * GitHub Actions event name.
 */
export type GitHubActionsEventName = typeof eventsName[number];
/**
 * Get the event name of the workflow run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_EVENT_NAME`
 * @returns {GitHubActionsEventName} Event name of the workflow run.
 * @example
 * ```ts
 * getWorkflowRunEventName();
 * //=> "workflow_dispatch"
 * ```
 */
export declare function getWorkflowRunEventName(): GitHubActionsEventName;
/**
 * Get the ID of the workflow run.
 *
 * This is unique for each workflow run within a repository, and does not change when re-run the workflow run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_RUN_ID`
 * @returns {string} ID of the workflow run.
 * @example
 * ```ts
 * getWorkflowRunID();
 * //=> 1658821493
 * ```
 */
export declare function getWorkflowRunID(): string;
/**
 * Get the job ID of the workflow run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_JOB`
 * @returns {string} Job ID of the workflow run.
 * @example
 * ```ts
 * getWorkflowRunJobID();
 * //=> "greeting_job"
 * ```
 */
export declare function getWorkflowRunJobID(): string;
/**
 * Get the run number of the workflow.
 *
 * This is unique for each run of a particular workflow in a repository, begins at `1` for the workflow's first run, and increments with each new run; This number does not change when re-run the workflow run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_RUN_NUMBER`
 * @returns {number} Run number of the workflow.
 * @example
 * ```ts
 * getWorkflowRunNumber();
 * //=> 3
 * ```
 */
export declare function getWorkflowRunNumber(): number;
export declare const referenceTypes: readonly ["branch", "tag"];
/**
 * GitHub reference type.
 */
export type GitHubReferenceType = typeof referenceTypes[number];
export interface GitHubReferenceMeta {
    /**
     * The name of the base reference or target branch of the pull request of the workflow run, only available when the event that trigger the workflow run is either `pull_request` or `pull_request_target`.
     * @example "main"
     */
    base?: string;
    /**
     * The fully formed reference of the branch or tag that trigger the workflow run.
     *
     * | **Event** | **Format** | **Description** |
     * |:--|:--|:--|
     * | `push` | `refs/heads/<branch_name>` | The branch or tag reference that was pushed. |
     * | `pull_request` | `refs/pull/<pr_number>/merge` | The pull request merge branch. |
     * | `release` | `refs/tags/<tag_name>` | The release tag created. |
     * | Other | `refs/heads/<branch_name>` | The branch or tag reference that trigger the workflow run. |
     * @example "refs/heads/feature-branch-1"
     */
    full: string;
    /**
     * The name of the head reference or source branch of the pull request of the workflow run, only available when the event that trigger the workflow run is either `pull_request` or `pull_request_target`.
     * @example "feature-branch-1"
     */
    head?: string;
    /**
     * Whether branch protections or rulesets are configured for the reference that trigger the workflow run.
     */
    protected: boolean;
    /**
     * The short reference name of the branch or tag that trigger the workflow run, this value matches the branch or tag name shown on GitHub.
     *
     * For pull requests, the format is `<pr_number>/merge`.
     * @example "feature-branch-1"
     */
    short: string;
    /**
     * The type of reference that trigger the workflow run.
     * @example "branch"
     */
    type: GitHubReferenceType;
}
/**
 * Get the reference of the workflow run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_BASE_REF`
 * >     - `GITHUB_HEAD_REF`
 * >     - `GITHUB_REF`
 * >     - `GITHUB_REF_NAME`
 * >     - `GITHUB_REF_PROTECTED`
 * >     - `GITHUB_REF_TYPE`
 * @returns {GitHubReferenceMeta} Reference of the workflow run.
 */
export declare function getWorkflowRunReference(): GitHubReferenceMeta;
/**
 * Get the retention days of the workflow run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_RETENTION_DAYS`
 * @returns {number} Retention days of the workflow run.
 * @example
 * ```ts
 * getWorkflowRunRetentionDays();
 * //=> 90
 * ```
 */
export declare function getWorkflowRunRetentionDays(): number;
/**
 * Get the run attempt of the workflow run.
 *
 * This is unique for each attempt of a particular workflow run in a repository, begins at `1` for the workflow run's first attempt, and increments with each re-run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_RUN_ATTEMPT`
 * @returns {number} Run attempt of the workflow run.
 * @example
 * ```ts
 * getWorkflowRunRunAttempt();
 * //=> 3
 * ```
 */
export declare function getWorkflowRunRunAttempt(): number;
/**
 * Get the URL of the workflow run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_REPOSITORY`
 * @returns {URL} URL of the workflow run.
 * @example
 * ```ts
 * getWorkflowRunURL();
 * //=> https://github.com/octocat/Hello-World/actions/runs/1658821493
 * ```
 */
export declare function getWorkflowRunURL(): URL;
export interface GitHubActionsWebhookEventPayloadRepository extends JSONObjectExtend {
    full_name?: string;
    html_url?: string;
    name: string;
    owner: {
        login: string;
        name?: string;
        [key: string]: JSONValueExtend;
    };
    [key: string]: JSONValueExtend;
}
/**
 * GitHub Actions webhook event payload.
 */
export interface GitHubActionsWebhookEventPayload extends JSONObjectExtend {
    action?: string;
    comment?: {
        id: number;
        [key: string]: JSONValueExtend;
    };
    installation?: {
        id: number;
        [key: string]: JSONValueExtend;
    };
    issue?: {
        number: number;
        html_url?: string;
        body?: string;
        [key: string]: JSONValueExtend;
    };
    pull_request?: {
        number: number;
        html_url?: string;
        body?: string;
        [key: string]: JSONValueExtend;
    };
    repository?: GitHubActionsWebhookEventPayloadRepository;
    sender?: {
        type: string;
        [key: string]: JSONValueExtend;
    };
    [key: string]: JSONValueExtend;
}
/**
 * Get the webhook event payload of the workflow run.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_EVENT_PATH`
 * >   - File System - Read (`read`)
 * >     - *Resources*
 * > - NodeJS (>= v20.9.0) 🧪
 * >   - File System - Read (`fs-read`)
 * >     - *Resources*
 * @returns {GitHubActionsWebhookEventPayload} Webhook event payload of the workflow run.
 */
export declare function getWorkflowRunWebhookEventPayload(): GitHubActionsWebhookEventPayload;
/**
 * Get the SHA of the workflow.
 *
 * > **🛡️ Require Runtime Permissions**
 * >
 * > - Deno
 * >   - Environment Variable (`env`)
 * >     - `GITHUB_WORKFLOW_SHA`
 * @returns {string} SHA of the workflow.
 */
export declare function getWorkflowSHA(): string;
//# sourceMappingURL=utility.d.ts.map